==> estateplat-common-1.2.3-20180801.025407-160-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXxcxjg.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
 * @version 1.0, 2016/7/3
 * @description 不动产信息查询结果表，记录每次不动产查询的结果信息，包括产权证号、不动产单元号、权利人、打印情况、经办人和详细信息等信息
 */
public class BdcXxcxjg {
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/3
     * @description 结果ID
     */
    @Id
    private String jgid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/3
     * @description 不动产单元号
     */
    private String bdcdyh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/3
     * @description 产权证号，包括不动产权证号、房产证号或土地证号
     */
    private String cqzh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/3
     * @description 权利人
     */
    private String qlr;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/3
     * @description 打印状态
     */
    private String dyzt;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/3
     * @description 打印时间
     */
    private String dysj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/3
     * @description 经办人
     */
    private String jbr;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/3
     * @description 查询结果详细内容
     */
    private String xxnr;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/3
     * @description 查询记录Id
     */
    private String jlid;

    /**
     * @author <a href="mailto:liangqing@gtmap.cn">liangqing</a>
     * @version 1.0, 2016/11/1
     * @description 查询结果是否上传附件
     */
    private String Upload;

    /**
     * @author bianwen
     * @description  查询结果备注

     */
    private String jgbz;
    /**
     * @author bianwen
     * @description   打印方式：0(fr3)，1(帆软)
     */
    private String dyfs;

    public String getJgwjlj() {
        return jgwjlj;
    }

    public void setJgwjlj(String jgwjlj) {
        this.jgwjlj = jgwjlj;
    }

    public String getDyfs() {
        return dyfs;
    }

    public void setDyfs(String dyfs) {
        this.dyfs = dyfs;
    }

    /**
     * @author bianwen
     * @description   帆软图片存储路径
     */
    private String jgwjlj;


    public String getJgbz() {
        return jgbz;
    }

    public void setJgbz(String jgbz) {
        this.jgbz = jgbz;
    }

    public String getJgid() {
        return jgid;
    }

    public void setJgid(String jgid) {
        this.jgid = jgid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getDyzt() {
        return dyzt;
    }

    public void setDyzt(String dyzt) {
        this.dyzt = dyzt;
    }

    public String getDysj() {
        return dysj;
    }

    public void setDysj(String dysj) {
        this.dysj = dysj;
    }

    public String getJbr() {
        return jbr;
    }

    public void setJbr(String jbr) {
        this.jbr = jbr;
    }

    public String getXxnr() {
        return xxnr;
    }

    public void setXxnr(String xxnr) {
        this.xxnr = xxnr;
    }

    public String getJlid() {
        return jlid;
    }

    public void setJlid(String jlid) {
        this.jlid = jlid;
    }

    public String getUpload() {
        return Upload;
    }

    public void setUpload(String upload) {
        Upload = upload;
    }
}

==> estateplat-common-1.2.4-20230420.125413-1161-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXxcxjg.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
 * @version 1.0, 2016/7/3
 * @description 不动产信息查询结果表，记录每次不动产查询的结果信息，包括产权证号、不动产单元号、权利人、打印情况、经办人和详细信息等信息
 */
public class BdcXxcxjg {
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/3
     * @description 结果ID
     */
    @Id
    private String jgid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/3
     * @description 不动产单元号
     */
    private String bdcdyh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/3
     * @description 产权证号，包括不动产权证号、房产证号或土地证号
     */
    private String cqzh;
    /**
     * @author <a href="mailto:wangzhiwen@gtmap.cn">wangzhiwen</a>
     * @version 1.0, 2022/12/12
     * @description 坐落
     */
    private String zl;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/3
     * @description 权利人
     */
    private String qlr;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/3
     * @description 打印状态
     */
    private String dyzt;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/3
     * @description 打印时间
     */
    private String dysj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/3
     * @description 经办人
     */
    private String jbr;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/3
     * @description 查询结果详细内容
     */
    private String xxnr;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/3
     * @description 查询记录Id
     */
    private String jlid;

    /**
     * @author <a href="mailto:liangqing@gtmap.cn">liangqing</a>
     * @version 1.0, 2016/11/1
     * @description 查询结果是否上传附件
     */
    private String Upload;

    /**
     * @author bianwen
     * @description  查询结果备注

     */
    private String jgbz;
    /**
     * @author bianwen
     * @description   打印方式：0(fr3)，1(帆软)
     */
    private String dyfs;

    public String getJgwjlj() {
        return jgwjlj;
    }

    public void setJgwjlj(String jgwjlj) {
        this.jgwjlj = jgwjlj;
    }

    public String getDyfs() {
        return dyfs;
    }

    public void setDyfs(String dyfs) {
        this.dyfs = dyfs;
    }

    /**
     * @author bianwen
     * @description   帆软图片存储路径
     */
    private String jgwjlj;


    public String getJgbz() {
        return jgbz;
    }

    public void setJgbz(String jgbz) {
        this.jgbz = jgbz;
    }

    public String getJgid() {
        return jgid;
    }

    public void setJgid(String jgid) {
        this.jgid = jgid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getDyzt() {
        return dyzt;
    }

    public void setDyzt(String dyzt) {
        this.dyzt = dyzt;
    }

    public String getDysj() {
        return dysj;
    }

    public void setDysj(String dysj) {
        this.dysj = dysj;
    }

    public String getJbr() {
        return jbr;
    }

    public void setJbr(String jbr) {
        this.jbr = jbr;
    }

    public String getXxnr() {
        return xxnr;
    }

    public void setXxnr(String xxnr) {
        this.xxnr = xxnr;
    }

    public String getJlid() {
        return jlid;
    }

    public void setJlid(String jlid) {
        this.jlid = jlid;
    }

    public String getUpload() {
        return Upload;
    }

    public void setUpload(String upload) {
        Upload = upload;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }
}
